# OKD
Online Knee Detection Model

-----------------------------------------------------------------------------------

This is an online knee detection model created to detect knee points of any given curve. 

Invented by Harish Sista. 
